const redis = require('async-redis');
const logger = require('tracer').console();

class RedisClient {

    constructor(host, port) {
        this.client = null;
        this.config = this.setConf(host, port);
        if (this.config) this.init();
    }

    init() {
        console.log(this.config);
        const client = redis.createClient(this.config);
        client.on("error", err => logger.error(err));
        client.on("connect", () => logger.log("redis service connected " + this.client.address));
        this.client = client;
    }

    setConf(host, port) {
        if (!host) {
            logger.error("[REDIS MESSAGE]:Please set the host!");
            return;
        }
        if (!port) {
            logger.error("[REDIS MESSAGE]:Please set the port!");
            return;
        }
        if (typeof host !== 'string' || typeof port !== 'number') {
            logger.error('[REDIS MESSAGE]:Configuration type error,please check!');
            return;
        }
        return {host:host,port:port};
    }

    static getInstance(host, port) {
        if (!RedisClient.instance) RedisClient.instance = new RedisClient(host, port);
        return RedisClient.instance;
    }
}

module.exports = RedisClient;




